import { GetScheduleTimeFrameRequest as GetScheduleTimeFrameRequest$1, GetScheduleTimeFrameResponse as GetScheduleTimeFrameResponse$1, ListScheduleTimeFramesRequest as ListScheduleTimeFramesRequest$1, ListScheduleTimeFramesResponse as ListScheduleTimeFramesResponse$1 } from './index.typings.js';
import '@wix/sdk-types';

/**
 * Information about the start and end dates of the first and last
 * [events](https://dev.wix.com/docs/rest/business-management/calendar/events-v3/introduction)
 * that belong to a [schedule](https://dev.wix.com/docs/rest/business-management/calendar/schedules-v3/introduction)
 * and whether any events follow an unlimited repetition pattern.
 */
interface ScheduleTimeFrame {
    /**
     * ID of the [schedule](https://dev.wix.com/docs/rest/business-management/calendar/schedules-v3/schedule-object)
     * to which the time frame belongs.
     * @format GUID
     * @readonly
     */
    id?: string | null;
    /**
     * Information about the presence of recurring events within the schedule.
     *
     * Supported values:
     * + `NONE`: No [events](https://dev.wix.com/docs/rest/business-management/calendar/events-v3/event-object) are scheduled within the schedule.
     * + `FINITE`: All recurring events within the schedule have a defined end date, or there are no recurring events.
     * + `INFINITE`: At least one recurring event within the schedule has no end date, meaning it follows an unlimited repetition pattern.
     * @readonly
     */
    status?: StatusWithLiterals;
    /**
     * Start date of the first [event](https://dev.wix.com/docs/rest/business-management/calendar/events-v3/event-object)
     * within the schedule. Identical to `event.start.localDate`. Available only if
     * `status` is set to `FINITE` or `INFINITE`.
     * @readonly
     */
    firstEventStartDate?: ZonedDate;
    /**
     * End date of the last [event](https://dev.wix.com/docs/rest/business-management/calendar/events-v3/event-object)
     * belonging to the schedule. Identical to `event.end.localDate`. Available only if
     * `status` is set to `FINITE`.
     * @readonly
     */
    lastEventEndDate?: ZonedDate;
    /**
     * Start date of the first [event](https://dev.wix.com/docs/rest/business-management/calendar/events-v3/event-object)
     * belonging to the schedule, adjusted to `timeZone` of the
     * [site properties](https://dev.wix.com/docs/rest/business-management/site-properties/properties/properties-object)
     * or the `timeZone` specified in the request.
     * Identical to `event.adjustedStart.localDate`.
     * @readonly
     */
    adjustedFirstEventStartDate?: ZonedDate;
    /**
     * End date of the last [event](https://dev.wix.com/docs/rest/business-management/calendar/events-v3/event-object)
     * belonging to the schedule, adjusted to `timeZone` of the
     * [site properties](https://dev.wix.com/docs/rest/business-management/site-properties/properties/properties-object)
     * or the `timeZone` specified in the request.
     * Identical to `event.adjustedEnd.localDate`.
     * @readonly
     */
    adjustedLastEventEndDate?: ZonedDate;
    /**
     * Revision number, which increments by 1 each time the schedule time frame is updated.
     * @readonly
     */
    revision?: string | null;
}
declare enum Status {
    UNKNOWN_STATUS = "UNKNOWN_STATUS",
    /** No [events](https://dev.wix.com/docs/rest/business-management/calendar/events-v3/event-object) that belong to the schedule. */
    NONE = "NONE",
    /** There are no recurring events or all recurring events belonging to the schedule have a defined end date. */
    FINITE = "FINITE",
    /** At least one recurring event belonging to the schedule has an unlimited repetition pattern (no end date). */
    INFINITE = "INFINITE"
}
/** @enumType */
type StatusWithLiterals = Status | 'UNKNOWN_STATUS' | 'NONE' | 'FINITE' | 'INFINITE';
/** A date time with a time zone, having the UTC offset and date determined by the server. */
interface ZonedDate {
    /**
     * Local date time in [ISO-8601 format](https://en.wikipedia.org/wiki/ISO_8601).
     * For example, `2024-01-30T13:30:00`.
     * Wix Calendar APIs ignore seconds.
     * @format LOCAL_DATE_TIME
     */
    localDate?: string | null;
    /**
     * Time zone in
     * [IANA tz database format](https://en.wikipedia.org/wiki/Tz_database).
     * For example, `America/New_York`.
     * @readonly
     */
    timeZone?: string | null;
    /**
     * UTC date time in [ISO-8601 format](https://en.wikipedia.org/wiki/ISO_8601).
     * For example, `2024-01-30T13:30:00`.
     * Not available for adjusted date fields.
     * @readonly
     */
    utcDate?: Date | null;
}
interface GetScheduleTimeFrameRequest {
    /**
     * [Schedule](https://dev.wix.com/docs/rest/business-management/calendar/schedules-v3/schedule-object)
     * ID for which to retrieve the schedule time frame.
     * @format GUID
     */
    id: string | null;
    /**
     * Time zone for adjusting the times of the returned schedule time frame.
     *
     * Default: `timeZone` of the [site properties](https://dev.wix.com/docs/rest/business-management/site-properties/properties/properties-object)
     */
    timeZone?: string | null;
}
interface GetScheduleTimeFrameResponse {
    /** Retrieved schedule time frame. */
    scheduleTimeFrame?: ScheduleTimeFrame;
}
interface ListScheduleTimeFramesRequest {
    /**
     * IDs of the schedules for which to retrieve schedule time frames.
     *
     * Min: 1 schedule ID
     * Max: 100 schedule IDs
     * @minSize 1
     * @maxSize 100
     * @format GUID
     */
    ids: string[];
    /**
     * Time zone for adjusting the times of the returned schedule time frames.
     *
     * Default: `timeZone` of the [site properties](https://dev.wix.com/docs/rest/business-management/site-properties/properties/properties-object)
     */
    timeZone?: string | null;
}
interface ListScheduleTimeFramesResponse {
    /** Retrieved schedule time frames. */
    scheduleTimeFrames?: ScheduleTimeFrame[];
}

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function getScheduleTimeFrame(): __PublicMethodMetaInfo<'GET', {
    id: string;
}, GetScheduleTimeFrameRequest$1, GetScheduleTimeFrameRequest, GetScheduleTimeFrameResponse$1, GetScheduleTimeFrameResponse>;
declare function listScheduleTimeFrames(): __PublicMethodMetaInfo<'GET', {}, ListScheduleTimeFramesRequest$1, ListScheduleTimeFramesRequest, ListScheduleTimeFramesResponse$1, ListScheduleTimeFramesResponse>;

export { type __PublicMethodMetaInfo, getScheduleTimeFrame, listScheduleTimeFrames };
